# ReverseWord MaintainSymbol

A python script that reverse a user's input
but keeps any symbol at it's original position after
the reverse.

-
## Installation
Run the following to install:

```python
pip install revwordmainsym
```

-
## Usage
```python
from revwordmainsym import manipulate

# Manipulate your string, example: "hell@o"
manipulate("hell@o")
> olle@h

```

